from multiprocessing.pool import ThreadPool
from multiprocessing import Pool as ProcessPool
from contextlib import contextmanager

from ppa import ui


@contextmanager
def thread_context(workers):
    try:
        pool = ThreadPool(workers)
        yield pool
        pool.close()
        pool.join()

    except Exception as e:
        ui.output_error(f"Error in workers: {e!s}")
        raise e


def thread_starmap(func, args_list, workers=4):
    with thread_context(workers) as pool:
        return pool.starmap(func, args_list)


def thread_map(func, args_list, workers=4):
    with thread_context(workers) as pool:
        return pool.map(func, args_list)


@contextmanager
def process_context(processes):
    try:
        pool = ProcessPool(processes=processes)
        yield pool
        pool.close()
        pool.join()

    except Exception as e:
        ui.output_error(f"Error in processes: {e!s}")
        raise e


def process_starmap(func, args_list, workers=4):
    with process_context(workers) as pool:
        return pool.starmap(func, args_list)


def process_map(func, args_list, workers=4):
    with process_context(workers) as pool:
        return pool.map(func, args_list)
