import socket
import validators

from typing import Tuple, List


class ResolutionError(Exception):
    pass


class InvalidFormat(Exception):
    pass


def lookup(hostname: str) -> str:
    try:
        return socket.gethostbyname(hostname)
    except Exception as e:
        raise ResolutionError(f"Failed to resolve IP address for hostname {hostname}: " f"{str(e)}")


def reverse(ip_address: str) -> Tuple[str, List[str], List[str]]:
    if not validators.ipv4(ip_address):
        raise InvalidFormat(f"{ip_address} is not a valid ipv4 address")
    try:
        return socket.gethostbyaddr(ip_address)
    except Exception as e:
        raise ResolutionError(f"Failed to get hostname for IP address {ip_address}: " f"{str(e)}")
