from . import _client
from ._records import incident_fields, _generate_named_tuples

ENDPOINT = "table/incident"


@_generate_named_tuples("Incident", incident_fields)
def get_all(service_now, display_value="false", attributes=None):
    return _client.get(service_now, ENDPOINT, params={"sysparm_display_value": display_value}, attributes=attributes,)


@_generate_named_tuples("Incident", incident_fields)
def by_sys_id(service_now, sys_id, display_value="false", attributes=None):
    return _client.get(
        service_now,
        "/".join([ENDPOINT, sys_id]),
        params={"sysparm_display_value": display_value},
        attributes=attributes,
    )


@_generate_named_tuples("Incident", incident_fields)
def search(service_now, display_value="false", attributes=None, **search_params):
    return _client.get(
        service_now,
        ENDPOINT,
        params={
            "sysparm_display_value": display_value,
            "sysparm_query": "^".join([f"{key}={value}" for key, value in search_params.items()]),
        }
        if search_params
        else None,
        attributes=attributes,
    )


@_generate_named_tuples("Incident", incident_fields)
def update(service_now, sys_id, display_value="false", **kwargs):
    return _client.put(
        service_now, "/".join([ENDPOINT, sys_id]), params={"sysparm_display_value": display_value}, data=kwargs
    )


@_generate_named_tuples("Incident", incident_fields)
def create(service_now, display_value="false", **kwargs):
    return _client.post(service_now, ENDPOINT, params={"sysparm_display_value": display_value}, data=kwargs)
