from . import _client
from ._records import user_fields, _generate_named_tuples

ENDPOINT = "table/sys_user"


@_generate_named_tuples("User", user_fields)
def get_all(service_now, attributes=None):
    return _client.get(service_now, ENDPOINT, attributes=attributes)


@_generate_named_tuples("User", user_fields)
def by_sys_id(service_now, sys_id, attributes=None):
    return _client.get(service_now, "/".join([ENDPOINT, sys_id]), attributes=attributes)


@_generate_named_tuples("User", user_fields)
def search(service_now, attributes=None, **search_params):
    return _client.get(
        service_now,
        ENDPOINT,
        params={"sysparm_query": "^".join([f"{key}={value}" for key, value in search_params.items()])}
        if search_params
        else None,
        attributes=attributes,
    )


@_generate_named_tuples("User", user_fields)
def update(service_now, sys_id, **kwargs):
    return _client.put(service_now, "/".join([ENDPOINT, sys_id]), data=kwargs)


@_generate_named_tuples("User", user_fields)
def create(service_now, **kwargs):
    return _client.post(service_now, ENDPOINT, data=kwargs)
